@@ -24,23 +24,24 @@ public:
 };
 typedef std::unique_ptr<::utility::string_t, zero_memory_deleter> plaintext_string;
 
-#if defined(_WIN32) && !defined(CPPREST_TARGET_XP)
-#if defined(__cplusplus_winrt)
+#ifdef _WIN32
+#if _WIN32_WINNT >= _WIN32_WINNT_VISTA
+#ifdef __cplusplus_winrt
 class winrt_encryption
 {
 public:
-    winrt_encryption() {}
+    winrt_encryption() = default;
     _ASYNCRTIMP winrt_encryption(const std::wstring& data);
     _ASYNCRTIMP plaintext_string decrypt() const;
 
 private:
     ::pplx::task<Windows::Storage::Streams::IBuffer ^> m_buffer;
 };
-#else
+#else  // ^^^ __cplusplus_winrt ^^^ // vvv !__cplusplus_winrt vvv
 class win32_encryption
 {
 public:
-    win32_encryption() {}
+    win32_encryption() = default;
     _ASYNCRTIMP win32_encryption(const std::wstring& data);
     _ASYNCRTIMP ~win32_encryption();
     _ASYNCRTIMP plaintext_string decrypt() const;
@@ -49,8 +50,9 @@ private:
     std::vector<char> m_buffer;
     size_t m_numCharacters;
 };
-#endif
-#endif
+#endif // __cplusplus_winrt
+#endif // _WIN32_WINNT >= _WIN32_WINNT_VISTA
+#endif // _WIN32
 } // namespace details
 
 /// <summary>
@@ -89,7 +91,7 @@ public:
         "This API is deprecated for security reasons to avoid unnecessary password copies stored in plaintext.")
     utility::string_t password() const
     {
-#if defined(_WIN32) && !defined(CPPREST_TARGET_XP)
+#if defined(_WIN32) && _WIN32_WINNT >= _WIN32_WINNT_VISTA
         return utility::string_t(*m_password.decrypt());
 #else
         return m_password;
@@ -105,7 +107,7 @@ public:
     details::plaintext_string _internal_decrypt() const
     {
         // Encryption APIs not supported on XP
-#if defined(_WIN32) && !defined(CPPREST_TARGET_XP)
+#if defined(_WIN32) && _WIN32_WINNT >= _WIN32_WINNT_VISTA
         return m_password.decrypt();
 #else
         return details::plaintext_string(new ::utility::string_t(m_password));
@@ -115,7 +117,7 @@ public:
 private:
     ::utility::string_t m_username;
 
-#if defined(_WIN32) && !defined(CPPREST_TARGET_XP)
+#if defined(_WIN32) && _WIN32_WINNT >= _WIN32_WINNT_VISTA
 #if defined(__cplusplus_winrt)
     details::winrt_encryption m_password;
 #else
@@ -151,13 +153,13 @@ public:
     /// <summary>
     /// Constructs a proxy with the default settings.
     /// </summary>
-    web_proxy() : m_address(_XPLATSTR("")), m_mode(use_default_) {}
+    web_proxy() : m_address(), m_mode(use_default_) {}
 
     /// <summary>
     /// Creates a proxy with specified mode.
     /// </summary>
     /// <param name="mode">Mode to use.</param>
-    web_proxy(web_proxy_mode mode) : m_address(_XPLATSTR("")), m_mode(static_cast<web_proxy_mode_internal>(mode)) {}
+    web_proxy(web_proxy_mode mode) : m_address(), m_mode(static_cast<web_proxy_mode_internal>(mode)) {}
 
     /// <summary>
     /// Creates a proxy explicitly with provided address.
