@@ -649,12 +649,19 @@ protected:
         if (mode == std::ios_base::in)
         {
             m_readOps.wait();
+            size_t current_pos = static_cast<size_t>(-1);
             switch (way)
             {
                 case std::ios_base::beg: return (pos_type)_seekrdpos_fsb(m_info, size_t(offset), sizeof(_CharType));
                 case std::ios_base::cur:
                     return (pos_type)_seekrdpos_fsb(m_info, size_t(m_info->m_rdpos + offset), sizeof(_CharType));
-                case std::ios_base::end: return (pos_type)_seekrdtoend_fsb(m_info, int64_t(offset), sizeof(_CharType));
+                case std::ios_base::end:
+                    current_pos = _seekrdtoend_fsb(m_info, int64_t(offset), sizeof(_CharType));
+                    if (current_pos == static_cast<size_t>(-1))
+                    {
+                        return -1;
+                    }
+                    return (pos_type)current_pos;
                 default:
                     // Fail on invalid input (_S_ios_seekdir_end)
                     assert(false);
