@@ -10,7 +10,8 @@
  * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
  ****/
 
-#include "stdafx.h"
+#include "cpprest/json.h"
+#include "unittestpp.h"
 
 using namespace web;
 using namespace utility;
